package com.develou.constraintlayout

import android.os.Bundle
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.constraintlayout.widget.ConstraintSet
import androidx.transition.TransitionManager

class MainActivity : AppCompatActivity() {
    private lateinit var constraintLayout: ConstraintLayout

    private var initialState = true
    private val startConstraints = ConstraintSet()
    private val endConstraints = ConstraintSet()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.p5_start_frame)

        constraintLayout = findViewById(R.id.constraintlayout)

        startConstraints.clone(constraintLayout)
        endConstraints.load(this, R.layout.p5_end_frame)

        // Habilita este método para crear el conjunto dinámicamente
        // createEndConstraints()

        findViewById<TextView>(R.id.move_button).setOnClickListener {
            moveIcons()
        }
    }

    private fun moveIcons() {
        val currentConstraints = if (initialState) endConstraints else startConstraints
        initialState = !initialState

        TransitionManager.beginDelayedTransition(constraintLayout)

        currentConstraints.applyTo(constraintLayout)
    }

    private fun createEndConstraints() {
        with(endConstraints) {
            clone(constraintLayout)

            constrainWidth(R.id.iv_boat, 88.px)
            constrainHeight(R.id.iv_boat, 88.px)
            constrainWidth(R.id.iv_car, 44.px)
            constrainHeight(R.id.iv_car, 44.px)

            connect(
                R.id.iv_boat,
                ConstraintSet.TOP,
                ConstraintSet.PARENT_ID,
                ConstraintSet.TOP
            )
            connect(
                R.id.iv_boat,
                ConstraintSet.BOTTOM,
                R.id.move_button,
                ConstraintSet.TOP
            )
            connect(
                R.id.iv_car,
                ConstraintSet.TOP,
                R.id.move_button,
                ConstraintSet.BOTTOM
            )
            connect(
                R.id.iv_car,
                ConstraintSet.BOTTOM,
                ConstraintSet.PARENT_ID,
                ConstraintSet.BOTTOM
            )
        }
    }
}